package org.rcisoft.bus.custinfo.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.bus.custinfo.entity.CustInfo;
import org.rcisoft.bus.custinfo.service.CustInfoService;

import java.util.List;

/**
* Created by cy on 2024年12月13日 上午9:58:24.
*/
@RestController
@RequestMapping("/custinfo")
public class CustInfoController extends CyPaginationController<CustInfo> {


    @Autowired
    private CustInfoService custInfoServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:tInfo:add')")
    @CyOpeLogAnno(title = "system-客户信息表管理-新增客户信息表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加客户信息表", notes="添加客户信息表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid CustInfo custInfo, BindingResult bindingResult) {
        CyPersistModel data = custInfoServiceImpl.persist(custInfo);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        custInfo);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:tInfo:delete')")
    @CyOpeLogAnno(title = "system-客户信息表管理-删除客户信息表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除客户信息表", notes="逻辑删除客户信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId,CustInfo custInfo) {
        custInfo.setBusinessId(businessId);
        CyPersistModel data = custInfoServiceImpl.removeLogical(custInfo);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:tInfo:delete')")
    @CyOpeLogAnno(title = "system-客户信息表管理-删除客户信息表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除客户信息表", notes="删除客户信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,CustInfo custInfo) {
        custInfo.setBusinessId(businessId);
        CyPersistModel data = custInfoServiceImpl.remove(custInfo);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:tInfo:update')")
    @CyOpeLogAnno(title = "system-客户信息表管理-修改客户信息表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改客户信息表", notes="修改客户信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid CustInfo custInfo, BindingResult bindingResult) {
        custInfo.setBusinessId(businessId);
        CyPersistModel data = custInfoServiceImpl.merge(custInfo);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        custInfo);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:tInfo:query')")
    @CyOpeLogAnno(title = "system-客户信息表管理-查询客户信息表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一客户信息表", notes="查询单一客户信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        custInfoServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:tInfo:list')")
    @CyOpeLogAnno(title = "system-客户信息表管理-查询客户信息表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询客户信息表集合", notes="查询客户信息表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(CustInfo custInfo) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            custInfoServiceImpl.findAll(custInfo));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:tInfo:list')")
    @CyOpeLogAnno(title = "system-客户信息表管理-查询客户信息表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询客户信息表集合", notes="分页查询客户信息表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(CustInfo custInfo) {
        custInfoServiceImpl.findAllByPagination(getPaginationUtility(), custInfo);
        return getGridModelResponse();
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:customer:export')")
    @CyOpeLogAnno(title = "system-客户信息表管理-查询客户信息表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出客户信息表信息", notes = "导出客户信息表信息")
    @GetMapping(value = "/export")
    public void outCustInfo(HttpServletResponse response,CustInfo custInfo,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="客户信息表信息.xls";break;
            case "1": excelName="客户信息表信息.xlsx";break;
            case "2": excelName="客户信息表信息.csv";break;
        }
        List<CustInfo> custInfoList = custInfoServiceImpl.export(custInfo);
        CyEpExcelUtil.exportExcel(custInfoList, "客户信息表信息", "客户信息表信息", CustInfo.class, excelName, response);
    }
}
