package org.rcisoft.bus.custrecharge.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.bus.custrecharge.entity.CustRecharge;
import org.rcisoft.bus.custrecharge.service.CustRechargeService;

import java.util.List;

/**
* Created by cy on 2024年12月13日 上午11:27:11.
*/
@RestController
@RequestMapping("/custrecharge")
public class CustRechargeController extends CyPaginationController<CustRecharge> {


    @Autowired
    private CustRechargeService custRechargeServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:tRecharge:add')")
    @CyOpeLogAnno(title = "system-客户消费表管理-新增客户消费表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加客户消费表", notes="添加客户消费表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid CustRecharge custRecharge, BindingResult bindingResult) {
        CyPersistModel data = custRechargeServiceImpl.persist(custRecharge);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        custRecharge);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:tRecharge:delete')")
    @CyOpeLogAnno(title = "system-客户消费表管理-删除客户消费表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除客户消费表", notes="逻辑删除客户消费表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId,CustRecharge custRecharge) {
        custRecharge.setBusinessId(businessId);
        CyPersistModel data = custRechargeServiceImpl.removeLogical(custRecharge);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:tRecharge:delete')")
    @CyOpeLogAnno(title = "system-客户消费表管理-删除客户消费表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除客户消费表", notes="删除客户消费表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,CustRecharge custRecharge) {
        custRecharge.setBusinessId(businessId);
        CyPersistModel data = custRechargeServiceImpl.remove(custRecharge);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:tRecharge:update')")
    @CyOpeLogAnno(title = "system-客户消费表管理-修改客户消费表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改客户消费表", notes="修改客户消费表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid CustRecharge custRecharge, BindingResult bindingResult) {
        custRecharge.setBusinessId(businessId);
        CyPersistModel data = custRechargeServiceImpl.merge(custRecharge);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        custRecharge);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:tRecharge:query')")
    @CyOpeLogAnno(title = "system-客户消费表管理-查询客户消费表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一客户消费表", notes="查询单一客户消费表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        custRechargeServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:tRecharge:list')")
    @CyOpeLogAnno(title = "system-客户消费表管理-查询客户消费表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询客户消费表集合", notes="查询客户消费表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(CustRecharge custRecharge) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            custRechargeServiceImpl.findAll(custRecharge));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:tRecharge:list')")
    @CyOpeLogAnno(title = "system-客户消费表管理-查询客户消费表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询客户消费表集合", notes="分页查询客户消费表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(CustRecharge custRecharge) {
        custRechargeServiceImpl.findAllByPagination(getPaginationUtility(), custRecharge);
        return getGridModelResponse();
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:recharge:export')")
    @CyOpeLogAnno(title = "system-客户消费表管理-查询客户消费表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出客户消费表信息", notes = "导出客户消费表信息")
    @GetMapping(value = "/export")
    public void outCustRecharge(HttpServletResponse response,CustRecharge custRecharge,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="客户消费表信息.xls";break;
            case "1": excelName="客户消费表信息.xlsx";break;
            case "2": excelName="客户消费表信息.csv";break;
        }
        List<CustRecharge> custRechargeList = custRechargeServiceImpl.export(custRecharge);
        CyEpExcelUtil.exportExcel(custRechargeList, "客户消费表信息", "客户消费表信息", CustRecharge.class, excelName, response);
    }
}
