package org.rcisoft.bus.custrecharge.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.bean.AdminProperties;
import org.rcisoft.bus.custinfo.entity.CustInfo;
import org.rcisoft.bus.custinfo.service.CustInfoService;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.bus.custrecharge.dao.CustRechargeRepository;
import org.rcisoft.bus.custrecharge.entity.CustRecharge;
import org.rcisoft.bus.custrecharge.service.CustRechargeService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.math.BigDecimal;
import java.util.Arrays;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年12月13日 上午11:27:11.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class CustRechargeServiceImpl extends ServiceImpl<CustRechargeRepository,CustRecharge>  implements CustRechargeService {


    @Autowired
    protected AdminProperties adminProperties;

    @Autowired
    CustInfoService custInfoServiceImpl;

    /**
    * 保存 客户消费表
    * @param custRecharge
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(CustRecharge custRecharge){

        if(custRecharge.getOrderNumber() != null){
            custRecharge.setStoreId(CyUserUtil.getAuthenDept());
            //根据id修改余额
            CustInfo custInfo = custInfoServiceImpl.findById(custRecharge.getCustomerId());
            BigDecimal newBalance = custInfo.getCustomerBalance().subtract(custRecharge.getConsumptionAmount());
            custInfo.setCustomerBalance(newBalance);
            custInfoServiceImpl.merge(custInfo);
        }

        //增加操作
        int line = baseMapper.insert(custRecharge);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            custRecharge.getBusinessId()+"的客户消费表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 客户消费表
    * @param custRecharge
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(CustRecharge custRecharge){
        int line = baseMapper.realDelete(custRecharge);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            custRecharge.getBusinessId()+"的客户消费表信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 客户消费表
    * @param custRecharge
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(CustRecharge custRecharge){
        custRecharge.setDeleted();
        int line = baseMapper.deleteById(custRecharge);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                custRecharge.getBusinessId()+"的客户消费表信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改 客户消费表
    * @param custRecharge
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(CustRecharge custRecharge){
        int line = baseMapper.updateById(custRecharge);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ custRecharge.getBusinessId()+"的客户消费表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 客户消费表
    * @param id
    * @return
    */
    @Override
    public CustRecharge findById(int id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 客户消费表
    * @param custRecharge
    * @return
    */
    @Override
    public IPage<CustRecharge> findAllByPagination(CyPageInfo<CustRecharge> paginationUtility,
        CustRecharge custRecharge){

        // 获取当前用户的角色ID
        String roleIds = CyUserUtil.getAuthenRoleIds();
        boolean adminKey = adminProperties.getAdmin().contains(CyUserUtil.getAuthenBusinessId());
        // 将角色ID字符串分割成数组，并去除每个ID前后的空白字符
        Set<String> userRoles = Arrays.stream(roleIds.split(","))
                .map(String::trim)
                .collect(Collectors.toSet());
        // 检查当前用户是否有管理员权限
        boolean isAdmin = userRoles.stream()
                .anyMatch(adminProperties.getAdminRole()::contains);
        // 根据是否是管理员调整查询条件
        if (!isAdmin || !adminKey) {
            custRecharge.setStoreId(CyUserUtil.getAuthenDept());
        }
        return baseMapper.queryCustRechargesPaged(paginationUtility,custRecharge);

    }

    /**
    * 查询list 客户消费表
    * @param custRecharge
    * @return
    */
    @Override
    public List<CustRecharge> findAll(CustRecharge custRecharge){
        return baseMapper.queryCustRecharges(custRecharge);

    }

    /**
    * 导出客户消费表
    * @return
    */
    @Override
    public List<CustRecharge> export(CustRecharge custRecharge) {

        // 获取当前用户的角色ID
        String roleIds = CyUserUtil.getAuthenRoleIds();
        boolean adminKey = adminProperties.getAdmin().contains(CyUserUtil.getAuthenBusinessId());
        // 将角色ID字符串分割成数组，并去除每个ID前后的空白字符
        Set<String> userRoles = Arrays.stream(roleIds.split(","))
                .map(String::trim)
                .collect(Collectors.toSet());
        // 检查当前用户是否有管理员权限
        boolean isAdmin = userRoles.stream()
                .anyMatch(adminProperties.getAdminRole()::contains);
        // 根据是否是管理员调整查询条件
        if (!isAdmin || !adminKey) {
            custRecharge.setStoreId(CyUserUtil.getAuthenDept());
        }

        List<CustRecharge> custRechargeList = baseMapper.queryCustRecharges(custRecharge);
        return custRechargeList;
    }

}
