package org.rcisoft.bus.storegoodsapply.controller;


/*固定导入*/

import cn.afterturn.easypoi.excel.ExcelExportUtil;
import cn.afterturn.easypoi.excel.entity.ExportParams;
import cn.afterturn.easypoi.excel.entity.enmus.ExcelType;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.rcisoft.bus.storegoodsapply.dto.AddStoreGoodsApplyDTO;
import org.rcisoft.bus.storegoodsapply.dto.ExportEntryDto;
import org.rcisoft.bus.storegoodsapply.entity.StoreGoodsApply;
import org.rcisoft.bus.storegoodsapply.service.StoreGoodsApplyService;
import org.rcisoft.bus.util.ExportExcelUtil;
import org.rcisoft.core.anno.CyEncryptSm4Anno;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.sys.dictionary.dao.DictDataRepository;
import org.rcisoft.sys.dictionary.dto.DictDataDTO;
import org.rcisoft.sys.dictionary.entity.DictData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.io.OutputStream;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.List;

/**
* Created by cy on 2024年5月29日 下午1:21:49.
*/
@RestController
@RequestMapping("/storegoodsapply")
@Slf4j
public class StoreGoodsApplyController extends CyPaginationController<StoreGoodsApply> {


    @Autowired
    private StoreGoodsApplyService storeGoodsApplyServiceImpl;
    @Autowired
    private DictDataRepository dictDataRepository;

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsApply:add')")
    @CyOpeLogAnno(title = "system-商品申请表管理-新增商品申请表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加商品申请表", notes="添加商品申请表")
    @PostMapping(value = "/add")
    public CyResult add(@RequestBody StoreGoodsApply storeGoodsApply) {
        CyPersistModel data = storeGoodsApplyServiceImpl.persist(storeGoodsApply);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
                storeGoodsApply);
    }
    @CyOpeLogAnno(title = "system-商品申请表管理-新增商品申请表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加商品申请表", notes="添加商品申请表")
    @PostMapping(value = "/in")
    public CyResult batchAdd(@RequestBody AddStoreGoodsApplyDTO wmsGoodsApply) {
        CyPersistModel data = storeGoodsApplyServiceImpl.batchPersist(wmsGoodsApply);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                wmsGoodsApply);
    }
    @CyOpeLogAnno(title = "system-商品申请表管理-新增商品申请表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加商品申请表", notes="添加商品申请表")
    @PostMapping(value = "/out")
    public CyResult batchAddOut(@RequestBody AddStoreGoodsApplyDTO wmsGoodsApply) {
        CyPersistModel data = storeGoodsApplyServiceImpl.batchOutPersist(wmsGoodsApply);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                wmsGoodsApply);
    }
    @CyOpeLogAnno(title = "获取单号", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="获取单号", notes="获取单号")
    @GetMapping(value = "/getCode")
    public CyResult getCode() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                storeGoodsApplyServiceImpl.appCode());
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsApply:delete')")
    @CyOpeLogAnno(title = "system-商品申请表管理-删除商品申请表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除商品申请表", notes="逻辑删除商品申请表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId, StoreGoodsApply storeGoodsApply) {
        storeGoodsApply.setBusinessId(businessId);
        CyPersistModel data = storeGoodsApplyServiceImpl.removeLogical(storeGoodsApply);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsApply:delete')")
    @CyOpeLogAnno(title = "system-商品申请表管理-删除商品申请表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除商品申请表", notes="删除商品申请表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId, StoreGoodsApply storeGoodsApply) {
        storeGoodsApply.setBusinessId(businessId);
        CyPersistModel data = storeGoodsApplyServiceImpl.remove(storeGoodsApply);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsApply:update')")
    @CyOpeLogAnno(title = "system-商品申请表管理-修改商品申请表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改商品申请表", notes="修改商品申请表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid StoreGoodsApply storeGoodsApply, BindingResult bindingResult) {
        storeGoodsApply.setBusinessId(businessId);
        CyPersistModel data = storeGoodsApplyServiceImpl.merge(storeGoodsApply);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
                storeGoodsApply);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsApply:query')")
    @CyOpeLogAnno(title = "system-商品申请表管理-查询商品申请表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一商品申请表", notes="查询单一商品申请表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        storeGoodsApplyServiceImpl.findById(businessId));
    }
    @CyOpeLogAnno(title = "system-商品申请表管理-查询商品申请表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一商品申请表", notes="查询单一商品申请表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detailOut/{businessId:\\w+}")
    public CyResult detailOut(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                storeGoodsApplyServiceImpl.findByIdOut(businessId));
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsApply:list')")
    @CyOpeLogAnno(title = "system-商品申请表管理-查询商品申请表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询商品申请表集合", notes="查询商品申请表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(StoreGoodsApply storeGoodsApply) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            storeGoodsApplyServiceImpl.findAll(storeGoodsApply));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsApply:list')")
    @CyOpeLogAnno(title = "system-商品申请表管理-查询商品申请表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询商品申请表集合", notes="分页查询商品申请表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(StoreGoodsApply storeGoodsApply) {
        storeGoodsApplyServiceImpl.findAllByPagination(getPaginationUtility(), storeGoodsApply);
        return getGridModelResponse();
    }
    @CyOpeLogAnno(title = "system-商品申请表管理-查询商品申请表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询商品申请表集合", notes="分页查询商品申请表集合")
    @GetMapping(value = "/listOut")
    public CyGridModel listOutByPagination(StoreGoodsApply storeGoodsApply) {
        storeGoodsApplyServiceImpl.OutfindAllByPagination(getPaginationUtility(), storeGoodsApply);
        return getGridModelResponse();
    }
    @CyOpeLogAnno(title = "system-商品申请表管理-查询商品申请表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出商品申请表信息", notes = "导出商品申请表信息")
    @GetMapping(value = "/export")
    public void outWmsGoodsApply(HttpServletResponse response, StoreGoodsApply storeGoodsApply, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="商品申请表信息.xls";break;
            case "1": excelName="商品申请表信息.xlsx";break;
            case "2": excelName="商品申请表信息.csv";break;
        }
        List<StoreGoodsApply> storeGoodsApplyList = storeGoodsApplyServiceImpl.export(storeGoodsApply);
        CyEpExcelUtil.exportExcel(storeGoodsApplyList, "商品申请表信息", "商品申请表信息", StoreGoodsApply.class, excelName, response);
    }
    @CyOpeLogAnno(title = "system-检查信息模板-检查信息模板", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出检查信息模板", notes = "导出检查信息模板")
    @GetMapping(value = "/downloadTemplate")
    @CyEncryptSm4Anno
    public void outDownloadTemplate(HttpServletResponse response, ExportEntryDto exportEntryDto) {
        OutputStream outputStream = null;
        Workbook workbook = null;
        try {
            response.setCharacterEncoding("UTF-8");
            response.setHeader("content-Type", "application/vnd.ms-excel");
            response.setHeader("Content-Disposition", "attachment;filename=" + URLEncoder.encode("试题数据信息.xlsx", "UTF-8"));
            ExportParams exportParams = new ExportParams();
            exportParams.setType(ExcelType.XSSF);
            List<ExportEntryDto> exportList = new ArrayList();
            workbook = ExcelExportUtil.exportExcel(exportParams, ExportEntryDto.class, exportList);
            Sheet sheet = workbook.getSheetAt(0);
            //数据字典
            DictDataDTO dictData = new DictDataDTO();
            dictData.setFlag("1");
            dictData.setDictType("GOODS_STYLE");
            List<DictData> dictDataList = dictDataRepository.querySysDictDatas(dictData);
            String[] goods_style = dictDataList.stream().map(DictData::getDictLabel).toArray(String[]::new);
            ExportExcelUtil.XSSFSetDropDownAndHidden(goods_style,workbook,sheet,1, 100000, 1, 1);

            DictDataDTO dictData1 = new DictDataDTO();
            dictData1.setFlag("1");
            dictData1.setDictType("GOODS_ART_NUMBER");
            List<DictData> dictDataList1 = dictDataRepository.querySysDictDatas(dictData1);
            String[] goodsArtNumber = dictDataList1.stream().map(DictData::getDictLabel).toArray(String[]::new);
            ExportExcelUtil.XSSFSetDropDownAndHidden(goodsArtNumber,workbook,sheet,1, 100000, 2, 2);

            DictDataDTO dictData2 = new DictDataDTO();
            dictData2.setFlag("1");
            dictData2.setDictType("GOODS_SEASON");
            List<DictData> dictDataList2 = dictDataRepository.querySysDictDatas(dictData2);
            String[] goodsSeason = dictDataList2.stream().map(DictData::getDictLabel).toArray(String[]::new);
            ExportExcelUtil.XSSFSetDropDownAndHidden(goodsSeason,workbook,sheet,1, 100000, 3, 3);

            DictDataDTO dictData3 = new DictDataDTO();
            dictData3.setFlag("1");
            dictData3.setDictType("GOODS_COLOUR");
            List<DictData> dictDataList3 = dictDataRepository.querySysDictDatas(dictData3);
            String[] goodsColour = dictDataList3.stream().map(DictData::getDictLabel).toArray(String[]::new);
            ExportExcelUtil.XSSFSetDropDownAndHidden(goodsColour,workbook,sheet,1, 100000, 4, 4);

            DictDataDTO dictData4 = new DictDataDTO();
            dictData1.setFlag("1");
            dictData1.setDictType("GOODS_NORMS");
            List<DictData> dictDataList4 = dictDataRepository.querySysDictDatas(dictData4);
            String[] goodsNorms = dictDataList4.stream().map(DictData::getDictLabel).toArray(String[]::new);
            ExportExcelUtil.XSSFSetDropDownAndHidden(goodsNorms,workbook,sheet,1, 100000, 5, 5);

            DictDataDTO dictData5 = new DictDataDTO();
            dictData1.setFlag("1");
            dictData1.setDictType("GOODS_SIZE");
            List<DictData> dictDataList5 = dictDataRepository.querySysDictDatas(dictData5);
            String[] goodsSize = dictDataList5.stream().map(DictData::getDictLabel).toArray(String[]::new);
            ExportExcelUtil.XSSFSetDropDownAndHidden(goodsSize,workbook,sheet,1, 100000, 6, 6);

            DictDataDTO dictData6 = new DictDataDTO();
            dictData1.setFlag("1");
            dictData1.setDictType("GOODS_DICT_NAME");
            List<DictData> dictDataList6 = dictDataRepository.querySysDictDatas(dictData6);
            String[] goodsDictName= dictDataList6.stream().map(DictData::getDictLabel).toArray(String[]::new);
            ExportExcelUtil.XSSFSetDropDownAndHidden(goodsDictName,workbook,sheet,1, 100000, 7, 7);

            DictDataDTO dictData7 = new DictDataDTO();
            dictData1.setFlag("1");
            dictData1.setDictType("GOODS_BRAND");
            List<DictData> dictDataList7 = dictDataRepository.querySysDictDatas(dictData7);
            String[] goodsBrand= dictDataList7.stream().map(DictData::getDictLabel).toArray(String[]::new);
            ExportExcelUtil.XSSFSetDropDownAndHidden(goodsBrand,workbook,sheet,1, 100000, 7, 7);

            outputStream = response.getOutputStream();
            workbook.write(outputStream);
        } catch (IOException e) {
            throw new CyServiceException(e.getMessage());
        } finally {
            try {
                if (outputStream != null) {
                    outputStream.close();
                }
            } catch (IOException var11) {
                log.info("context:" + var11);
            }
        }
    }


//    @CyOpeLogAnno(title = "system-检查申请管理-导入检查申请数据", businessType = CyLogTypeEnum.IMPORT)
//    @ApiOperation(value = "导入检查申请数据", notes = "导入检查申请数据")
//    @PostMapping(value = "/importGoodsData")
//    @CyEncryptSm4Anno
//    public CyResult importGoodsData(MultipartFile file) {
//        return CyResultGenUtil.builder(new CyPersistModel(1),
//                CyMessCons.MESSAGE_ALERT_SUCCESS,
//                CyMessCons.MESSAGE_ALERT_ERROR,
//                wmsGoodsApplyServiceImpl.importGoodsExcel(file));
//    }
}
