package org.rcisoft.bus.storegoodslog.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.rcisoft.bean.AdminProperties;
import org.rcisoft.bus.storegoodsapply.entity.StoreGoodsApply;
import org.rcisoft.bus.storegoodsapply.service.StoreGoodsApplyService;
import org.rcisoft.bus.storegoodslog.dao.StoreGoodsLogRepository;
import org.rcisoft.bus.storegoodslog.entity.StoreGoodsLog;
import org.rcisoft.bus.storegoodslog.service.StoreGoodsLogService;
import org.rcisoft.bus.storegoodsstock.dao.StoreGoodsStockRepository;
import org.rcisoft.bus.storegoodsstock.entity.StoreGoodsStock;
import org.rcisoft.bus.storegoodsstock.service.StoreGoodsStockService;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.Arrays;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * Created by cy on 2024年5月29日 下午1:21:49.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class StoreGoodsLogServiceImpl extends ServiceImpl<StoreGoodsLogRepository, StoreGoodsLog> implements StoreGoodsLogService {

    @Autowired
    protected AdminProperties adminProperties;

    @Autowired
    private StoreGoodsLogService storeGoodsLogServiceImpl;

    @Autowired
    private StoreGoodsApplyService storeGoodsApplyServiceImpl;

    @Autowired
    private StoreGoodsStockRepository storeGoodsStockRepository;

    @Autowired
    private StoreGoodsStockService storeGoodsStockRepositoryImpl;

    /**
     * 保存 商品记录表
     *
     * @param storeGoodsLog
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(StoreGoodsLog storeGoodsLog) {
        //增加操作
        int line = baseMapper.insert(storeGoodsLog);
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                storeGoodsLog.getBusinessId() + "的商品记录表信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除 商品记录表
     *
     * @param storeGoodsLog
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(StoreGoodsLog storeGoodsLog) {
        int line = baseMapper.realDelete(storeGoodsLog);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                storeGoodsLog.getBusinessId() + "的商品记录表信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 商品记录表
     *
     * @param storeGoodsLog
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(StoreGoodsLog storeGoodsLog) {
        storeGoodsLog.setDeleted();
        int line = baseMapper.deleteById(storeGoodsLog);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                storeGoodsLog.getBusinessId() + "的商品记录表信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 商品记录表
     *
     * @param storeGoodsLog
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(StoreGoodsLog storeGoodsLog) {

        StoreGoodsLog oldStoreGoodsLog = storeGoodsLogServiceImpl.findById(storeGoodsLog.getBusinessId());

        if(storeGoodsLog.getIsReturn().equals("1")){
            for (StoreGoodsLog box : storeGoodsLogServiceImpl.findAll(oldStoreGoodsLog)) {
                StoreGoodsStock goodsStock = storeGoodsStockRepository.selectByGoodsId(box.getGoodsId());
                goodsStock.setGoodsCounts(goodsStock.getGoodsCounts() + box.getGoodsCounts());
                // 返回库存
                storeGoodsStockRepositoryImpl.updateCounts(goodsStock);
            }
        }

        StoreGoodsApply storeGoodsApply = new StoreGoodsApply();
        storeGoodsApply.setBusinessId(oldStoreGoodsLog.getApplyId());
        storeGoodsApply.setIsReturn(storeGoodsLog.getIsReturn());
        storeGoodsApplyServiceImpl.merge(storeGoodsApply);

        oldStoreGoodsLog.setIsReturn("1");
        int line = baseMapper.updateById(oldStoreGoodsLog);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + storeGoodsLog.getBusinessId() + "的商品记录表信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 商品记录表
     *
     * @param id
     * @return
     */
    @Override
    public StoreGoodsLog findById(int id) {
        return baseMapper.selectById(id);
    }

    /**
     * 分页查询 商品记录表
     *
     * @param storeGoodsLog
     * @return
     */
    @Override
    public IPage<StoreGoodsLog> findAllByPagination(CyPageInfo<StoreGoodsLog> paginationUtility,
                                                    StoreGoodsLog storeGoodsLog) {
        return baseMapper.queryWmsGoodsLogsPaged(paginationUtility, storeGoodsLog);

    }

    /**
     * 查询list 商品记录表
     *
     * @param storeGoodsLog
     * @return
     */
    @Override
    public List<StoreGoodsLog> findAll(StoreGoodsLog storeGoodsLog) {
        return baseMapper.queryWmsGoodsLogs(storeGoodsLog);

    }

    /**
     * 导出商品记录表
     *
     * @return
     */
    @Override
    public List<StoreGoodsLog> export(StoreGoodsLog storeGoodsLog) {

        // 获取当前用户的角色ID
        String roleIds = CyUserUtil.getAuthenRoleIds();
        boolean adminKey = adminProperties.getAdmin().contains(CyUserUtil.getAuthenBusinessId());
        // 将角色ID字符串分割成数组，并去除每个ID前后的空白字符
        Set<String> userRoles = Arrays.stream(roleIds.split(","))
                .map(String::trim)
                .collect(Collectors.toSet());
        // 检查当前用户是否有管理员权限
        boolean isAdmin = userRoles.stream()
                .anyMatch(adminProperties.getAdminRole()::contains);
        // 根据是否是管理员调整查询条件
        if (!isAdmin || !adminKey) {
            storeGoodsLog.setStoreId(CyUserUtil.getAuthenDept());
        }

        List<StoreGoodsLog> storeGoodsLogList = baseMapper.queryWmsGoodsLogs(storeGoodsLog);
        return storeGoodsLogList;
    }
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel batchPersist(List<StoreGoodsLog> addLogList) {
        baseMapper.batchPersist(addLogList);
        return new CyPersistModel(1);
    }

    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel updateStatus(StoreGoodsApply storeGoodsLog) {
        int line = baseMapper.updateStatus(storeGoodsLog);
        return new CyPersistModel(line);
    }
}
