package org.rcisoft.bus.storegoodsstock.controller;


/*固定导入*/

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.bus.storegoodsstock.dto.StoreGoodsStockPageResultsDto;
import org.rcisoft.bus.storegoodsstock.entity.StoreGoodsStock;
import org.rcisoft.bus.storegoodsstock.service.StoreGoodsStockService;
import org.rcisoft.bus.wmsgoods.entity.WmsGoods;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;

/**
* Created by cy on 2024年5月29日 下午1:21:49.
*/
@RestController
@RequestMapping("/storegoodsstock")
public class StoreGoodsStockController extends CyPaginationController<StoreGoodsStockPageResultsDto> {


    @Autowired
    private StoreGoodsStockService storeGoodsStockServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsStock:add')")
    @CyOpeLogAnno(title = "system-库存管理表管理-新增库存管理表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加库存管理表", notes="添加库存管理表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid StoreGoodsStock storeGoodsStock, BindingResult bindingResult) {
        CyPersistModel data = storeGoodsStockServiceImpl.persist(storeGoodsStock);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
                storeGoodsStock);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsStock:delete')")
    @CyOpeLogAnno(title = "system-库存管理表管理-删除库存管理表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除库存管理表", notes="逻辑删除库存管理表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId, StoreGoodsStock storeGoodsStock) {
        storeGoodsStock.setBusinessId(businessId);
        CyPersistModel data = storeGoodsStockServiceImpl.removeLogical(storeGoodsStock);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsStock:delete')")
    @CyOpeLogAnno(title = "system-库存管理表管理-删除库存管理表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除库存管理表", notes="删除库存管理表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId, StoreGoodsStock storeGoodsStock) {
        storeGoodsStock.setBusinessId(businessId);
        CyPersistModel data = storeGoodsStockServiceImpl.remove(storeGoodsStock);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @PreAuthorize("@cyPerm.hasPerm('sys:goodsStock:update')")
    @CyOpeLogAnno(title = "system-库存管理表管理-修改库存管理表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改库存管理表", notes="修改库存管理表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid StoreGoodsStock storeGoodsStock, BindingResult bindingResult) {
        storeGoodsStock.setBusinessId(businessId);
        CyPersistModel data = storeGoodsStockServiceImpl.merge(storeGoodsStock);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
                storeGoodsStock);
    }


    @CyOpeLogAnno(title = "system-库存管理表管理-修改库存管理表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改库存管理表", notes="修改库存管理表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/updateCounts/{businessId:\\w+}")
    public CyResult updateCounts(@PathVariable int businessId, @Valid StoreGoodsStock storeGoodsStock, BindingResult bindingResult) {
        storeGoodsStock.setBusinessId(businessId);
        CyPersistModel data = storeGoodsStockServiceImpl.updateCounts(storeGoodsStock);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                storeGoodsStock);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsStock:query')")
    @CyOpeLogAnno(title = "system-库存管理表管理-查询库存管理表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一库存管理表", notes="查询单一库存管理表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        storeGoodsStockServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsStock:list')")
    @CyOpeLogAnno(title = "system-库存管理表管理-查询库存管理表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询库存管理表集合", notes="查询库存管理表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(StoreGoodsStock storeGoodsStock) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            storeGoodsStockServiceImpl.findAll(storeGoodsStock));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsStock:list')")
    @CyOpeLogAnno(title = "system-库存管理表管理-查询库存管理表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询库存管理表集合", notes="分页查询库存管理表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(StoreGoodsStockPageResultsDto wmsGoodsStock) {
        storeGoodsStockServiceImpl.findAllByPagination(getPaginationUtility(), wmsGoodsStock);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-库存管理表管理-查询库存管理表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出库存管理表信息", notes = "导出库存管理表信息")
    @GetMapping(value = "/export")
    public void outWmsGoodsStock(HttpServletResponse response, StoreGoodsStock storeGoodsStock, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="库存管理表信息.xls";break;
            case "1": excelName="库存管理表信息.xlsx";break;
            case "2": excelName="库存管理表信息.csv";break;
        }
        List<StoreGoodsStock> storeGoodsStockList = storeGoodsStockServiceImpl.export(storeGoodsStock);
        CyEpExcelUtil.exportExcel(storeGoodsStockList, "库存管理表信息", "库存管理表信息", StoreGoodsStock.class, excelName, response);
    }


    @CyOpeLogAnno(title = "system-商品信息表管理-查询商品", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询商品", notes="查询商品")
    @GetMapping(value = "/detailByCode")
    public CyResult detailByCode(WmsGoods wmsGoods) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                storeGoodsStockServiceImpl.queryWmsGoodsStock(wmsGoods));
    }
}
