package org.rcisoft.bus.wmsgoodsprice.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.bus.wmsgoodsprice.entity.WmsGoodsPrice;
import org.rcisoft.bus.wmsgoodsprice.service.WmsGoodsPriceService;

import java.util.List;

/**
* Created by cy on 2024年12月12日 下午4:27:44.
*/
@RestController
@RequestMapping("/wmsgoodsprice")
public class WmsGoodsPriceController extends CyPaginationController<WmsGoodsPrice> {


    @Autowired
    private WmsGoodsPriceService wmsGoodsPriceServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsPrice:add')")
    @CyOpeLogAnno(title = "system-价格管理表管理-新增价格管理表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加价格管理表", notes="添加价格管理表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid WmsGoodsPrice wmsGoodsPrice, BindingResult bindingResult) {
        CyPersistModel data = wmsGoodsPriceServiceImpl.persist(wmsGoodsPrice);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        wmsGoodsPrice);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsPrice:delete')")
    @CyOpeLogAnno(title = "system-价格管理表管理-删除价格管理表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除价格管理表", notes="逻辑删除价格管理表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId,WmsGoodsPrice wmsGoodsPrice) {
        wmsGoodsPrice.setBusinessId(businessId);
        CyPersistModel data = wmsGoodsPriceServiceImpl.removeLogical(wmsGoodsPrice);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsPrice:delete')")
    @CyOpeLogAnno(title = "system-价格管理表管理-删除价格管理表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除价格管理表", notes="删除价格管理表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,WmsGoodsPrice wmsGoodsPrice) {
        wmsGoodsPrice.setBusinessId(businessId);
        CyPersistModel data = wmsGoodsPriceServiceImpl.remove(wmsGoodsPrice);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsPrice:update')")
    @CyOpeLogAnno(title = "system-价格管理表管理-修改价格管理表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改价格管理表", notes="修改价格管理表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid WmsGoodsPrice wmsGoodsPrice, BindingResult bindingResult) {
        wmsGoodsPrice.setBusinessId(businessId);
        CyPersistModel data = wmsGoodsPriceServiceImpl.merge(wmsGoodsPrice);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        wmsGoodsPrice);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsPrice:query')")
    @CyOpeLogAnno(title = "system-价格管理表管理-查询价格管理表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一价格管理表", notes="查询单一价格管理表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        wmsGoodsPriceServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsPrice:list')")
    @CyOpeLogAnno(title = "system-价格管理表管理-查询价格管理表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询价格管理表集合", notes="查询价格管理表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(WmsGoodsPrice wmsGoodsPrice) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            wmsGoodsPriceServiceImpl.findAll(wmsGoodsPrice));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsPrice:list')")
    @CyOpeLogAnno(title = "system-价格管理表管理-查询价格管理表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询价格管理表集合", notes="分页查询价格管理表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(WmsGoodsPrice wmsGoodsPrice) {
        wmsGoodsPriceServiceImpl.findAllByPagination(getPaginationUtility(), wmsGoodsPrice);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-价格管理表管理-查询价格管理表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出价格管理表信息", notes = "导出价格管理表信息")
    @GetMapping(value = "/export")
    public void outWmsGoodsPrice(HttpServletResponse response,WmsGoodsPrice wmsGoodsPrice,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="价格管理表信息.xls";break;
            case "1": excelName="价格管理表信息.xlsx";break;
            case "2": excelName="价格管理表信息.csv";break;
        }
        List<WmsGoodsPrice> wmsGoodsPriceList = wmsGoodsPriceServiceImpl.export(wmsGoodsPrice);
        CyEpExcelUtil.exportExcel(wmsGoodsPriceList, "价格管理表信息", "价格管理表信息", WmsGoodsPrice.class, excelName, response);
    }
}
